@@ -1,4 +1,5 @@
 from hypothesis import given
+from hypothesis.strategies import composite, datetimes, lists, text, uuids
 
 from mythx_models.response import (
     ProjectCreationResponse,
@@ -7,7 +8,25 @@ from mythx_models.response import (
     ProjectStatusResponse,
     ProjectUpdateResponse,
 )
-from tests import project_dict_response, project_list_response
+
+
+@composite
+def project_dict_response(draw):
+    return {
+        "id": str(draw(uuids(version=4))),
+        "name": draw(text()),
+        "description": draw(text()),
+        "created": draw(datetimes()),
+        "modified": draw(datetimes()),
+    }
+
+
+@composite
+def project_list_response(draw, min_size, max_size):
+    projects = draw(
+        lists(project_dict_response(), min_size=min_size, max_size=max_size)
+    )
+    return {"projects": projects, "total": len(projects)}
 
 
 @given(project_list_response(min_size=0, max_size=10))
